@@ -48,7 +48,7 @@ class TaskControl(object):
 
         # name of task in order to be executed
         # this the order as in the dodo file. the real execution
-        # order might be different if the dependecies require so.
+        # order might be different if the dependencies require so.
         self._def_order = []
         # list of tasks selected to be executed
         self.selected_tasks = None
@@ -110,8 +110,9 @@ class TaskControl(object):
 
         # 2) now go through all dependencies and check if they are target from
         # another task.
-        # FIXME - when used with delayed tasks needs to check if
-        #         any new target matches any old file_dep.
+        # Note: When used with delayed tasks.
+        #       It does NOT check if a delayed-task's target is a file_dep
+        #       from another previously created task.
         for task in task_list:
             TaskControl.add_implicit_task_dep(targets, task, task.file_dep)
 
@@ -266,7 +267,7 @@ class TaskControl(object):
 
 
 class ExecNode(object):
-    """Each task will have an instace of this
+    """Each task will have an instance of this.
     This used to keep track of waiting events and the generator for dep nodes
 
     @ivar run_status (str): contains the result of Dependency.get_status().status
@@ -353,6 +354,7 @@ class TaskDispatcher(object):
     def __init__(self, tasks, targets, selected_tasks):
         self.tasks = tasks
         self.targets = targets
+        self.selected_tasks = selected_tasks
 
         self.nodes = {} # key task-name, value: ExecNode
         # queues
@@ -420,7 +422,7 @@ class TaskDispatcher(object):
              - None values are of no interest and are filtered out
                by the decorator no_none
 
-        note that after a 'wait' is sent it is the reponsability of the
+        note that after a 'wait' is sent it is the responsibility of the
         caller to ensure the current ExecNode cleared all its waiting
         before calling `next()` again on this generator
         """
